import { useState } from "react";
import { Input, Button, Card, Steps, Tag, Spin, message } from "antd";
import { SearchOutlined, SafetyCertificateOutlined } from "@ant-design/icons";
import ProgressHeader from "./ProgressHeader";

interface FeedbackStatus {
	status: "pending" | "processing" | "resolved";
	ticketId: string;
	submittedDate: string;
	lastUpdate: string;
	title: string;
}

const { Step } = Steps;

export default function LetterProgressPage() {
	const [feedbackId, setFeedbackId] = useState("");
	const [status, setStatus] = useState<FeedbackStatus | null>(null);
	const [loading, setLoading] = useState(false);
	const [error, setError] = useState("");

	const validateInput = () => {
		if (!feedbackId.trim()) {
			setError("请输入有效的问题编号");
			return false;
		}
		if (!/^USAF-\d{4}-\d{4}$/.test(feedbackId)) {
			setError("问题编号格式不正确，应为USAF-YYYY-NNNN");
			return false;
		}
		setError("");
		return true;
	};

	const mockLookup = () => {
		if (!validateInput()) return;

		setLoading(true);
		setTimeout(() => {
			setStatus({
				status: "processing",
				ticketId: feedbackId,
				submittedDate: "2025-01-15",
				lastUpdate: "2025-01-21",
				title: "Aircraft Maintenance Schedule Inquiry",
			});
			setLoading(false);
		}, 1000);
	};

	const getStatusColor = (status: string) => {
		switch (status) {
			case "pending":
				return "orange";
			case "processing":
				return "blue";
			case "resolved":
				return "green";
			default:
				return "gray";
		}
	};

	return (
		<div
			className="min-h-screen shadow-elegant border-2 border-white  rounded-xl    bg-gradient-to-b from-slate-100 to-slate-50 "
			style={{ fontFamily: "Arial, sans-serif" }}>
			<ProgressHeader></ProgressHeader>
			{/* Main Content */}
			<main className="container mx-auto p-6">
				<div className="space-y-4">
					<div className="flex gap-4">
						<Input
							prefix={
								<SearchOutlined className=" text-secondary-300" />
							}
							size="large"
							value={feedbackId}
							onChange={(e) => setFeedbackId(e.target.value)}
							placeholder="请输入信件编码查询处理状态"
							status={error ? "error" : ""}
							className="border border-gray-300"
						/>
						<Button
							type="primary"
							size="large"
							loading={loading}
							onClick={mockLookup}
						>
							查询
						</Button>
					</div>
					{error && (
						<p className="text-red-600 text-sm">{error}</p>
					)}
				</div>

				{/* Results Section */}
				{status && (
					<Card>
						<div className="space-y-6">
							{/* Header */}
							<div className="flex items-center justify-between border-b pb-4">
								<h2 className="text-xl font-semibold text-[#003366]">
									Ticket Details
								</h2>
								<Tag
									color={getStatusColor(status.status)}
									className="font-bold uppercase">
									{status.status}
								</Tag>
							</div>

							{/* Details Grid */}
							<div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
								<div>
									<p className="text-sm text-gray-600">
										Ticket ID
									</p>
									<p className="font-medium text-[#003366]">
										{status.ticketId}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										Submitted Date
									</p>
									<p className="font-medium text-[#003366]">
										{status.submittedDate}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										Last Update
									</p>
									<p className="font-medium text-[#003366]">
										{status.lastUpdate}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										Subject
									</p>
									<p className="font-medium text-[#003366]">
										{status.title}
									</p>
								</div>
							</div>

							{/* Progress Timeline */}
							<div className="mt-8">
								<Steps
									current={
										status.status === "pending"
											? 0
											: status.status === "processing"
												? 1
												: 2
									}
									className="usa-progress">
									<Step
										title="Submitted"
										description="Ticket received"
										icon={<SafetyCertificateOutlined />}
									/>
									<Step
										title="In Progress"
										description="Under review"
										icon={<SafetyCertificateOutlined />}
									/>
									<Step
										title="Resolved"
										description="Ticket completed"
										icon={<SafetyCertificateOutlined />}
									/>
								</Steps>
							</div>
						</div>
					</Card>
				)}
			</main>
		</div>
	);
}
